@@ -5,30 +5,47 @@ package Verilog::Std;
 use Config;
 use IO::File;
 use File::Path;
-use Verilog::Language;
 use Carp;
 use strict;
 
-use vars qw($VERSION);
+use vars qw ($VERSION);
 
 ######################################################################
 #### Configuration Section
 
-$VERSION = '2.468';
+$VERSION = '3.200';
 
 #######################################################################
-# It's a PITRA to have pure datafiles get installed properly, so we have
-# the std text here in this package.
+# ACCESSORS
+
+our $_Std_Data;
+
+sub std {
+    if (!$_Std_Data) {
+	my @out;
+	foreach (<DATA>) {
+	    last if $_ =~ /^__END__/;
+	    push @out, $_;
+	}
+	$_Std_Data = join('',@out);
+    }
+    return $_Std_Data;
+}
+
+#######################################################################
+# It's a PITRA to have pure datafiles get installed properly,
+# so we just paste our text into this package.
+1;
+__DATA__
 
-our $_Std_Text = <<EOF;
 `line 1 "Perl_Verilog::Std_module" 0
 // Verilog-Perl Verilog::Std
-// The basis for this package is described in IEEE 1800-2017 Annex G
+// The basis for this package is described in IEEE 1800 Annex C
 package std;
 
 class semaphore;
    extern function new(int keyCount = 0);
-   extern function void put(int keyCount = 1);
+   extern task put(int keyCount = 1);
    extern task get(int keyCount = 1);
    extern function int try_get(int keyCount = 1);
 endclass
@@ -48,38 +65,21 @@ class process;
    typedef enum { FINISHED, RUNNING, WAITING, SUSPENDED, KILLED } state;
    extern static function process self();
    extern function state status();
-   extern function void kill();
+   extern task kill();
    extern task await();
-   extern function void suspend();
-   extern function void resume();
+   extern task suspend();
+   extern task resume();
 endclass
 
-// randomize is here, however the parsing rules are special,
-// For example there is "(null)", variable arguments, and "with {...}"
-// randomize really should be a language keyword.
-function int randomize();
-endfunction
+//Compiler built-in due to specialized arguments
+//function int randomize( ... );
+// randomize( variable_identifier {, variable_identifier } ) [ with constraint_block ];
 
 endpackage : std
 
 import std::*;
 
-EOF
-
-#######################################################################
-# ACCESSORS
-
-sub std {
-    my $std = shift || Verilog::Language::language_standard();
-    if ($std =~ /^1800/) {
-	return $_Std_Text;
-    } else {
-	return "";
-    }
-}
-
-#######################################################################
-1;
+__END__
 
 =pod
 
@@ -103,11 +103,9 @@ SystemVerilog standard.
 
 =over 4
 
-=item std({I<standard>})
+=item std
 
-Return the definition of the std package.  Optionally pass the language
-standard, defaulting to what Verilog::Language::language_standard returns if
-unspecified.
+Return the definition of the std package.
 
 =back
 
@@ -117,7 +115,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2009-2019 by Wilson Snyder.  This package is free software; you
+Copyright 2009-2009 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License
 Version 2.0.
